@@ -30,7 +30,9 @@ def generate(url=None, acl=None, start_time=None, duration=None,
         token_parts.append("st=%d" % start_time)
     token_parts.append("exp=%d" % expiration)
     if acl is not None:
-        token_parts.append("acl=%s" % _escape_to_lower(acl))
+        acl_list = acl if type(acl) is list else [acl]
+        acl_list = [_escape_to_lower(a) for a in acl_list] 
+        token_parts.append("acl=%s" % "!".join(acl_list))
     to_sign = list(token_parts)
     if url is not None and acl is None:
         to_sign.append("url=%s" % _escape_to_lower(url))
