@@ -41,6 +41,7 @@ API_TEST_TRANS_SCALE100_STR = "c_scale,l_{},w_100".format(API_TEST_TRANS_OVERLAY
 API_TEST_TRANS_SEPIA = {"crop": "lfill", "width": 400, "effect": "sepia"}
 API_TEST_TRANS_SEPIA_STR = "c_lfill,e_sepia,w_400"
 API_TEST_PRESET = "api_test_upload_preset"
+ASSET_FOLDER = "asset_folder"
 PREFIX = "test_folder_{}".format(SUFFIX)
 MAPPING_TEST_ID = "api_test_upload_mapping_{}".format(SUFFIX)
 RESTORE_TEST_ID = "api_test_restore_{}".format(SUFFIX)
@@ -128,10 +129,20 @@ class ApiTest(unittest.TestCase):
     @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
     def test_rate_limits(self):
         """ should include details of the account's rate limits"""
-        result = api.ping()
-        self.assertIsInstance(result.rate_limit_allowed, int)
-        self.assertIsInstance(result.rate_limit_reset_at, tuple)
-        self.assertIsInstance(result.rate_limit_remaining, int)
+        results = [
+            api.ping(),
+            api.root_folders(),
+            api.resource_types(),
+        ]
+
+        for result in results:
+            self.assertIsInstance(result.rate_limit_allowed, int)
+            self.assertIsInstance(result.rate_limit_reset_at, tuple)
+            self.assertIsInstance(result.rate_limit_remaining, int)
+
+            self.assertGreater(result.rate_limit_allowed, 0)
+            self.assertIsNotNone(result.rate_limit_reset_at)
+            self.assertGreater(result.rate_limit_remaining, 0)
 
     @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
     def test01_resource_types(self):
@@ -296,6 +307,17 @@ class ApiTest(unittest.TestCase):
         self.assertEqual(resource["bytes"], 3381)
         self.assertEqual(len(resource["derived"]), 1, "{} should have one derived resource.".format(API_TEST_ID))
 
+    @patch('urllib3.request.RequestMethods.request')
+    @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
+    def test_resources_by_asset_folder(self, mocker):
+        mocker.return_value = MOCK_RESPONSE
+        api.resources_by_asset_folder(ASSET_FOLDER, context=True, tags=True)
+        args, kargs = mocker.call_args
+        self.assertTrue(get_uri(args).endswith('/resources/by_asset_folder'))
+        self.assertTrue(get_params(args)['context'])
+        self.assertTrue(get_params(args)['tags'])
+        self.assertEqual(ASSET_FOLDER, get_param(mocker, "asset_folder"))
+
     @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
     def test07a_resource_quality_analysis(self):
         """ should allow getting resource quality analysis """
@@ -644,6 +666,15 @@ class ApiTest(unittest.TestCase):
         notification_url = get_param(mocker, 'notification_url')
         self.assertEqual(notification_url, "http://example.com")
 
+    @patch('urllib3.request.RequestMethods.request')
+    @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
+    def test21_update_metadata(self, mocker):
+        """ should support notification_url param """
+        mocker.return_value = MOCK_RESPONSE
+        api.update("api_test", metadata={"key": "value"})
+        metadata = get_param(mocker, "metadata")
+        self.assertEqual(metadata, "key=value")
+
     @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
     def test22_raw_conversion(self):
         """ should support requesting raw_convert """
@@ -771,6 +802,17 @@ class ApiTest(unittest.TestCase):
         with six.assertRaisesRegex(self, BadRequest, 'Illegal value'):
             api.update(API_TEST_ID, background_removal="illegal")
 
+    @patch('urllib3.request.RequestMethods.request')
+    @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
+    def test33_update_asset_folder(self, mocker):
+        """Should pass folder decoupling params """
+        mocker.return_value = MOCK_RESPONSE
+        api.update(API_TEST_ID, asset_folder="folder_new_update", display_name="new_display_name", unique_display_name=True)
+        self.assertEqual("folder_new_update", get_param(mocker, "asset_folder"))
+        self.assertEqual("new_display_name", get_param(mocker, "display_name"))
+        self.assertTrue(get_param(mocker, "unique_display_name"))
+
+
     @unittest.skipUnless(cloudinary.config().api_secret, "requires api_key/api_secret")
     @unittest.skip("For this test to work, 'Auto-create folders' should be enabled in the Upload Settings, " +
                    "and the account should be empty of folders. " +
